==> amn-9.2.0-en-download.zip: amn-9.2.0-en/webhelp/amn-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database adabasmanager
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var adabasmanager = {
    baseurls: ["../"],
    varname: "adabasmanager",
        tree: [
            { url: "about/about.htm", title: "About this Documentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Document Conventions" },
                  { url: "about/online_information.htm", title: "Online Information and Support" },
                  { url: "about/data_protection.htm", title: "Data Protection" },
              ]
            },
            { url: "relnotes/relnotes.htm", title: "Release Notes",
              tree: [
                  { url: "relnotes/general.htm", title: "General" },
                  { url: "relnotes/newfeat92.htm", title: "New and Modified Features in Version 9.2" },
                  { url: "relnotes/dropfeat90.htm", title: "Dropped Features" },
                  { url: "relnotes/doc.htm", title: "Documentation" },
              ]
            },
            { url: "concepts/concepts.htm", title: "Concepts",
              tree: [
                  { url: "concepts/what.htm", title: "What is Adabas Manager?" },
                  { url: "concepts/who.htm", title: "Who will use Adabas Manager?" },
              ]
            },
            { url: "install/inst-over.htm", title: "Installation",
              tree: [
                  { url: "install/inst-sysreq.htm", title: "System Requirements" },
                  { url: "install/inst-info.htm", title: "Important Information" },
                  { url: "install/inst-amn.htm", title: "Installing Adabas Manager" },
                  { url: "install/inst-upgrade.htm", title: "Upgrading Adabas Manager" },
                  { url: "install/inst-uninstall.htm", title: "Uninstalling Adabas Manager" },
                  { url: "install/inst-migrate.htm", title: "Migrating from System Management Hub (SMH) to Adabas Manager (AMN)" },
              ]
            },
            { url: "config/config.htm", title: "Configuration" },
            { url: "user/use-over.htm", title: "Using Adabas Manager",
              tree: [
                  { url: "user/amn-start.htm", title: "Starting and Ending an Adabas Manager Session" },
                  { url: "user/amn-usage.htm", title: "Common Usage Scenarios on Linux and Windows" },
                  { url: "user/DatabaseAdministration.htm", title: "Database Administration on Linux and Windows" },
                  { url: "user/DatabaseAdministrationMF.htm", title: "Database Administration on Mainframe" },
                  { url: "user/NetWork.htm", title: "Entire Net-Work Administration" },
                  { url: "user/AdaAudit.htm", title: "Adabas Auditing" },
                  { url: "user/docker.htm", title: "Building an Adabas Manager Docker Image" },
              ]
            },
            { url: "utils/pref.htm", title: "Adabas Utilities",
              tree: [
                  { url: "utils/over.htm", title: "Overview" },
                  { url: "utils/bck.htm", title: "ADABCK (Dump And Restore Database Or Files)" },
                  { url: "utils/cmp.htm", title: "ADACMP (Compression Of Data)" },
                  { url: "utils/dbm.htm", title: "ADADBM (Database Modification)" },
                  { url: "utils/dcu.htm", title: "ADADCU (Decompression Of Data)" },
                  { url: "utils/fdu.htm", title: "ADAFDU (File Definition)" },
                  { url: "utils/fin.htm", title: "ADAFIN (File Information Report)" },
                  { url: "utils/mup.htm", title: "ADAMUP (Mass Add And Delete)" },
                  { url: "utils/opr.htm", title: "ADAOPR (Operator Utility)" },
                  { url: "utils/ord.htm", title: "ADAORD (Reorder Database Or Files, Export/Import Files)" },
                  { url: "utils/rep.htm", title: "ADAREP (Database Report)" },
                  { url: "utils/uld.htm", title: "ADAULD (File Unloading)" },
              ]
            },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: adabasmanager });

==> amn-9.4.0-en-download.zip: amn-9.4.0-en/webhelp/amn-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database adabasmanager
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var adabasmanager = {
    baseurls: ["../"],
    varname: "adabasmanager",
        tree: [
            { url: "about/about.htm", title: "About this Documentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Document Conventions" },
                  { url: "about/online_information.htm", title: "Online Information and Support" },
                  { url: "about/data_protection.htm", title: "Data Protection" },
              ]
            },
            { url: "relnotes/relnotes.htm", title: "Release Notes",
              tree: [
                  { url: "relnotes/general.htm", title: "General" },
                  { url: "relnotes/newfeat.htm", title: "New and Modified Features in Version 9.4" },
                  { url: "relnotes/dropfeat.htm", title: "Dropped Features" },
                  { url: "relnotes/doc.htm", title: "Documentation" },
              ]
            },
            { url: "concepts/concepts.htm", title: "Concepts",
              tree: [
                  { url: "concepts/what.htm", title: "What is Adabas Manager?" },
                  { url: "concepts/who.htm", title: "Who will use Adabas Manager?" },
              ]
            },
            { url: "install/inst-over.htm", title: "Installation",
              tree: [
                  { url: "install/inst-sysreq.htm", title: "System Requirements" },
                  { url: "install/inst-info.htm", title: "Important Information" },
                  { url: "install/inst-amn.htm", title: "Installing Adabas Manager" },
                  { url: "install/inst-upgrade.htm", title: "Upgrading Adabas Manager" },
                  { url: "install/inst-uninstall.htm", title: "Uninstalling Adabas Manager" },
                  { url: "install/inst-migrate.htm", title: "Migrating from System Management Hub (SMH) to Adabas Manager (AMN)" },
              ]
            },
            { url: "config/config.htm", title: "Configuration" },
            { url: "user/use-over.htm", title: "Using Adabas Manager",
              tree: [
                  { url: "user/amn-start.htm", title: "Starting and Ending an Adabas Manager Session" },
                  { url: "user/amn-usage.htm", title: "Common Usage Scenarios on Linux and Windows" },
                  { url: "user/DatabaseAdministration.htm", title: "Database Administration on Linux and Windows" },
                  { url: "user/DatabaseAdministrationMF.htm", title: "Database Administration on Mainframe" },
                  { url: "user/NetWork.htm", title: "Entire Net-Work Administration" },
                  { url: "user/AdaAudit.htm", title: "Adabas Auditing" },
                  { url: "user/eventreplicator.htm", title: "Event Replicator for Adabas" },
                  { url: "user/docker.htm", title: "Building an Adabas Manager Docker Image" },
                  { url: "user/target_adapter.htm", title: "Event Replicator Target Adapter (Target Adapter)" },
              ]
            },
            { url: "utils/pref.htm", title: "Adabas Utilities",
              tree: [
                  { url: "utils/over.htm", title: "Overview" },
                  { url: "utils/bck.htm", title: "ADABCK (Dump And Restore Database Or Files)" },
                  { url: "utils/clp.htm", title: "ADACLP (Command Log Report)" },
                  { url: "utils/cmp.htm", title: "ADACMP (Compression Of Data)" },
                  { url: "utils/dbm.htm", title: "ADADBM (Database Modification)" },
                  { url: "utils/dcu.htm", title: "ADADCU (Decompression Of Data)" },
                  { url: "utils/err.htm", title: "ADAERR (Error File Report)" },
                  { url: "utils/fdu.htm", title: "ADAFDU (File Definition)" },
                  { url: "utils/fin.htm", title: "ADAFIN (File Information Report)" },
                  { url: "utils/frm.htm", title: "ADAFRM (Format And Create A New Database)" },
                  { url: "utils/inv.htm", title: "ADAINV (Creating, Removing And Verifying Inverted Lists)" },
                  { url: "utils/mup.htm", title: "ADAMUP (Mass Add And Delete)" },
                  { url: "utils/opr.htm", title: "ADAOPR (Operator Utility)" },
                  { url: "utils/ord.htm", title: "ADAORD (Reorder Database Or Files, Export/Import Files)" },
                  { url: "utils/plp.htm", title: "ADAPLP (Protection Log Printout)" },
                  { url: "utils/pri.htm", title: "ADAPRI (Print Adabas Blocks)" },
                  { url: "utils/rec.htm", title: "ADAREC (Recovery Of Database Or Files)" },
                  { url: "utils/rep.htm", title: "ADAREP (Database Report)" },
                  { url: "utils/sel.htm", title: "ADASEL (PLOG Selection Tool)" },
                  { url: "utils/uld.htm", title: "ADAULD (File Unloading)" },
                  { url: "utils/vfy.htm", title: "ADAVFY (Database Consistency Check)" },
              ]
            },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: adabasmanager });
